summaryrefslogtreecommitdiffstats
path: root/korganizer/eventarchiver.h
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/eventarchiver.h')
-rw-r--r--korganizer/eventarchiver.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/korganizer/eventarchiver.h b/korganizer/eventarchiver.h
index 01897b7ec..8da86debf 100644
--- a/korganizer/eventarchiver.h
+++ b/korganizer/eventarchiver.h
@@ -19,8 +19,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef EVENTARCHIVER_H
#define EVENTARCHIVER_H
@@ -44,19 +44,20 @@ using namespace KCal;
* Be sure to set mArchiveAction and mArchiveFile before a manual archiving
* mAutoArchive is used for auto archiving.
*/
-class EventArchiver : public QObject
+class EventArchiver : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
- EventArchiver( TQObject* parent = 0, const char* name = 0 );
+ EventArchiver( TQObject* tqparent = 0, const char* name = 0 );
virtual ~EventArchiver();
/**
* Delete or archive events once
* @param calendar the calendar to archive
* @param limitDate all events *before* the limitDate (not included) will be deleted/archived.
* @param widget parent widget for message boxes
* Confirmation and "no events to process" dialogs will be shown
*/
void runOnce( Calendar* calendar, const TQDate& limitDate, TQWidget* widget );
@@ -64,7 +65,7 @@ class EventArchiver : public QObject
/**
* Delete or archive events. This is called regularly, when auto-archiving is enabled
* @param calendar the calendar to archive
* @param widget parent widget for message boxes
* @param withGUI whether this is called from the dialog, so message boxes should be shown.
* Note that error dialogs like "cannot save" are shown even if from this method, so widget
* should be set in all cases.
@@ -44,19 +44,20 @@ using namespace KCal;
* @param calendar the calendar to archive
* @param limitDate all events *before* the limitDate (not included) will be deleted/archived.
- * @param widget parent widget for message boxes
+ * @param widget tqparent widget for message boxes
* Confirmation and "no events to process" dialogs will be shown
*/
@@ -64,7 +65,7 @@ class EventArchiver : public QObject
* Delete or archive events. This is called regularly, when auto-archiving is enabled
* @param calendar the calendar to archive
- * @param widget parent widget for message boxes
+ * @param widget tqparent widget for message boxes
* @param withGUI whether this is called from the dialog, so message boxes should be shown.
* Note that error dialogs like "cannot save" are shown even if from this method, so widget